'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = Modal;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactModal = require('react-modal');

var _reactModal2 = _interopRequireDefault(_reactModal);

var _Button = require('cspace-input/lib/components/Button');

var _Button2 = _interopRequireDefault(_Button);

var _MiniButton = require('cspace-input/lib/components/MiniButton');

var _MiniButton2 = _interopRequireDefault(_MiniButton);

var _Modal = require('../../styles/cspace-layout/Modal.css');

var _Modal2 = _interopRequireDefault(_Modal);

var _Overlay = require('../../styles/cspace-layout/Overlay.css');

var _Overlay2 = _interopRequireDefault(_Overlay);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var renderCloseButton = function renderCloseButton(config) {
  var closeButtonClassName = config.closeButtonClassName,
      closeButtonLabel = config.closeButtonLabel,
      showCloseButton = config.showCloseButton,
      onCloseButtonClick = config.onCloseButtonClick;


  if (!showCloseButton) {
    return null;
  }

  return _react2.default.createElement(
    _MiniButton2.default,
    {
      className: closeButtonClassName,
      name: 'close',
      onClick: onCloseButtonClick
    },
    closeButtonLabel
  );
};

var propTypes = {
  children: _react.PropTypes.node,
  className: _react.PropTypes.string,
  contentLabel: _react.PropTypes.string,
  isOpen: _react.PropTypes.bool,
  title: _react.PropTypes.node,
  acceptButtonClassName: _react.PropTypes.string,
  acceptButtonDisabled: _react.PropTypes.bool,
  acceptButtonLabel: _react.PropTypes.string,
  cancelButtonClassName: _react.PropTypes.string,
  cancelButtonDisabled: _react.PropTypes.bool,
  cancelButtonLabel: _react.PropTypes.string,
  closeButtonClassName: _react.PropTypes.string,
  closeButtonLabel: _react.PropTypes.string,
  showAcceptButton: _react.PropTypes.bool,
  showCancelButton: _react.PropTypes.bool,
  showCloseButton: _react.PropTypes.bool,
  renderButtonBar: _react.PropTypes.func,
  renderCloseButton: _react.PropTypes.func,
  onAcceptButtonClick: _react.PropTypes.func,
  onCancelButtonClick: _react.PropTypes.func,
  onCloseButtonClick: _react.PropTypes.func
};

var defaultProps = {
  renderCloseButton: renderCloseButton,
  contentLabel: 'Modal',
  acceptButtonLabel: 'OK',
  cancelButtonLabel: 'Cancel',
  closeButtonLabel: '×',
  showAcceptButton: true,
  showCancelButton: true,
  showCloseButton: true,
  renderButtonBar: function renderButtonBar(config) {
    var acceptButtonClassName = config.acceptButtonClassName,
        acceptButtonDisabled = config.acceptButtonDisabled,
        acceptButtonLabel = config.acceptButtonLabel,
        cancelButtonClassName = config.cancelButtonClassName,
        cancelButtonDisabled = config.cancelButtonDisabled,
        cancelButtonLabel = config.cancelButtonLabel,
        showAcceptButton = config.showAcceptButton,
        showCancelButton = config.showCancelButton,
        onAcceptButtonClick = config.onAcceptButtonClick,
        onCancelButtonClick = config.onCancelButtonClick;


    var acceptButton = void 0;

    if (showAcceptButton) {
      acceptButton = _react2.default.createElement(
        _Button2.default,
        {
          className: acceptButtonClassName,
          disabled: acceptButtonDisabled,
          name: 'accept',
          onClick: onAcceptButtonClick
        },
        acceptButtonLabel
      );
    }

    var cancelButton = void 0;

    if (showCancelButton) {
      cancelButton = _react2.default.createElement(
        _Button2.default,
        {
          className: cancelButtonClassName,
          disabled: cancelButtonDisabled,
          name: 'cancel',
          onClick: onCancelButtonClick
        },
        cancelButtonLabel
      );
    }

    return _react2.default.createElement(
      'div',
      null,
      cancelButton,
      acceptButton
    );
  }
};

function Modal(props) {
  var children = props.children,
      className = props.className,
      contentLabel = props.contentLabel,
      isOpen = props.isOpen,
      title = props.title,
      renderButtonBar = props.renderButtonBar,
      acceptButtonClassName = props.acceptButtonClassName,
      acceptButtonDisabled = props.acceptButtonDisabled,
      acceptButtonLabel = props.acceptButtonLabel,
      cancelButtonClassName = props.cancelButtonClassName,
      cancelButtonDisabled = props.cancelButtonDisabled,
      cancelButtonLabel = props.cancelButtonLabel,
      closeButtonClassName = props.closeButtonClassName,
      closeButtonLabel = props.closeButtonLabel,
      showAcceptButton = props.showAcceptButton,
      showCancelButton = props.showCancelButton,
      showCloseButton = props.showCloseButton,
      onAcceptButtonClick = props.onAcceptButtonClick,
      onCancelButtonClick = props.onCancelButtonClick,
      onCloseButtonClick = props.onCloseButtonClick,
      remainingProps = _objectWithoutProperties(props, ['children', 'className', 'contentLabel', 'isOpen', 'title', 'renderButtonBar', 'acceptButtonClassName', 'acceptButtonDisabled', 'acceptButtonLabel', 'cancelButtonClassName', 'cancelButtonDisabled', 'cancelButtonLabel', 'closeButtonClassName', 'closeButtonLabel', 'showAcceptButton', 'showCancelButton', 'showCloseButton', 'onAcceptButtonClick', 'onCancelButtonClick', 'onCloseButtonClick']);

  var closeButton = renderCloseButton({
    closeButtonClassName: closeButtonClassName,
    closeButtonLabel: closeButtonLabel,
    showCloseButton: showCloseButton,
    onCloseButtonClick: onCloseButtonClick
  });

  var buttonBar = renderButtonBar({
    acceptButtonClassName: acceptButtonClassName,
    acceptButtonDisabled: acceptButtonDisabled,
    acceptButtonLabel: acceptButtonLabel,
    cancelButtonClassName: cancelButtonClassName,
    cancelButtonDisabled: cancelButtonDisabled,
    cancelButtonLabel: cancelButtonLabel,
    showAcceptButton: showAcceptButton,
    showCancelButton: showCancelButton,
    onAcceptButtonClick: onAcceptButtonClick,
    onCancelButtonClick: onCancelButtonClick
  });

  return _react2.default.createElement(
    _reactModal2.default,
    _extends({}, remainingProps, {
      contentLabel: contentLabel,
      isOpen: isOpen,
      className: _Modal2.default.common,
      overlayClassName: _Overlay2.default.common,
      portalClassName: className
    }),
    _react2.default.createElement(
      'header',
      null,
      _react2.default.createElement(
        'div',
        null,
        title
      ),
      closeButton
    ),
    _react2.default.createElement(
      'div',
      null,
      children
    ),
    _react2.default.createElement(
      'footer',
      null,
      buttonBar
    )
  );
}

Modal.propTypes = propTypes;
Modal.defaultProps = defaultProps;

Modal.setAppElement = function (element) {
  return _reactModal2.default.setAppElement(element);
};